## cdist-type__rvm(7)

### Evax Software

`<contact@evax.fr>`

## 1. NAME

cdist-type__rvm - Install rvm for a given user

## 2. DESCRIPTION

RVM is the Ruby enVironment Manager for the Ruby programming language.

## 3. REQUIRED PARAMETERS

state
  Either "present" or "absent".

## 4. EXAMPLES

    # Install rvm for user billie
    __rvm billie --state present

    # Remove rvm
    __rvm billie --state absent

## 5. SEE ALSO

- cdist-type(7)
- cdist-type__rvm_ruby(7)
- cdist-type__rvm_gemset(7)
- cdist-type__rvm_gem(7)

## 6. COPYING

Copyright (C) 2012 Evax Software. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).